\name{testGeneFamilies.binomial}
\alias{testGeneFamilies.binomial}
\title{Identified significant gene families between two samples using the binomial model}
\description{
Test for significant gene families using the binomial model.
}
\usage{
testGeneFamilies.binomial(data)
}
\arguments{
\item{data}{$2\times n$ matrix containing counts}
}
\details{
\code{testGeneFamilies.binomial} performs an exact binomial test for each row
in the data matrix. Assume that $X_1\sim Po(M_1p_1)$ and $X_2\sim
Po(M_2p_2)$ where $M_1$ and $M_2$ are the total number of
observations from two metagenomes. It follows that 
\[
X_1|X_1+X_2=n \sim Bin\left(n,\frac{M_1p_1}{M_1p_1+M_2p_2}\right)
\]
and the binomial test is testing whether $p_1=p_2$. The test can be seen as an approximation of the
hypergeometric counterpart (\code{\link{testGeneFamilies.hypergeometric}}).


\code{testGeneFamilies.binomial} is usually called 
implicitly by using the 'binomial' method in \code{\link{testGeneFamilies}}.
}
\value{\code{testGeneFamilies.binomial} returns a list with the following
elements
\item{PValues}{A list of p-values}
\item{Rankings.detail}{A list additional elements containing details about
the ranking}
}
\seealso{
\code{\link{testGeneFamilies}},
\code{\link{testGeneFamilies.hypergeometric}},
\code{\link{testGeneFamilies.gaussian}},
\code{\link{testGeneFamilies.poisson}}
}
\examples{
counts<-cbind(rpois(10, 100), rpois(10, seq(50,300, length=10)))
testGeneFamilies.binomial(counts)
}
\keyword{htest}
