\name{trendPlot.family}
\alias{trendPlot.family}
\title{Plots the result from a gene-centric direct comparison using the Poisson model}
\description{
\code{trendPlot.family} plots the result from a gene-centric regression
analysis. The normalized rate is shown for each sample together with the
fitted trend line. This function requires that the Poisson model has been
fitted to the data. 
}
\usage{
trendPlot.family(stat.families, family, x.axis.lab=NULL, xlim, ylim,
		 col.points="black", col.text="grey30", col.trend="red3", 
		 xlab="", plot.counts=TRUE, main, 
		 print.pvalue=FALSE, print.pvalue.pos="topright", print.pvalue.cex=1.3, 
		 add=FALSE, ...)
}
\details{}
\arguments{
\item{stat.families}{results from a regression analysis using the Poisson
model (\code{\link{testGeneFamilies.regression}})}
\item{family}{character string indicating which gene family to plot}
\item{x.axis.lab}{character vector with labels for the ticks at the x-axis}
\item{xlim}{x limit of the plot. A suitable value is calculated if omitted}
\item{ylim}{y limit of the plot. A suitable value is calculated if omitted}
\item{col}{the color on the character vector with four element indicating the colors of the
bars of the first group, the bars of the second group, the horizontal line
of the first group and the horizontal line of the second group}
\item{col.points}{color of the data points}
\item{col.text}{color of the text showing the number of counts}
\item{col.trend}{color of the fitted trend line}
\item{xlab}{label of the x-axis}
\item{plot.counts}{should the counts be plotted next to the data points?}
\item{main}{the title of the plot. If omitted, the annotation of the gene
family will be used}
\item{print.pvalue}{should the corresponding p-value be printed?}
\item{print.pvalue.pos}{where should be p-value be placed? This argument is
analogous to the location keywords used by \code{\link{legend}}.}
\item{print.pvalue.cex}{the magnification of the text used to print the
p-value}
\item{add}{should a new plot be opened or should the figure be added to an
existing plot?}
\item{...}{additional arguments for \code{\link{plot}}}
}
\examples{
\dontrun{
data(OceanCOG)
po.stat<-testGeneFamilies.regression(OceanCOG, covariates=c(10, 70, 130, 200, 500, 770, 4000), log.covariates=T)
trendPlot.family(po.stat, family="COG0415")
}}
\seealso{
\code{\link{trendPlot}}, \code{\link{trendPlot.category}},
\code{\link{groupPlot}},\code{\link{groupPlot.family}},\code{\link{groupPlot.category}}
}
\keyword{hplot}
